@@ -49,9 +49,14 @@
 
 package com.openexchange.mobile.api.facade.endpoints.requests;
 
+import lombok.AccessLevel;
+import lombok.AllArgsConstructor;
+import lombok.NoArgsConstructor;
 import lombok.Value;
 
 @Value
+@AllArgsConstructor
+@NoArgsConstructor(force = true, access = AccessLevel.PRIVATE)
 public class AuthenticationRequestBody {
 
     String username;
