@@ -51,9 +51,14 @@ package com.openexchange.mobile.api.facade.endpoints.requests;
 
 import java.util.List;
 
+import lombok.AccessLevel;
+import lombok.AllArgsConstructor;
+import lombok.NoArgsConstructor;
 import lombok.Value;
 
 @Value
+@AllArgsConstructor
+@NoArgsConstructor(force = true, access = AccessLevel.PRIVATE)
 public class MailsRequestBody {
 
     String folderId;
