@@ -50,6 +50,7 @@
 package com.openexchange.mobile.api.facade.models;
 
 import java.util.List;
+import java.util.Map;
 
 import lombok.AllArgsConstructor;
 import lombok.Data;
@@ -74,6 +75,9 @@ public class Config {
     @Wither
     private List<Capability> capabilities;
 
+    @Wither
+    private Map<String, String> properties;
+
     @Wither
     private boolean multipleAccountsEnabled;
 
